/*!
  * Licensed Materials - Property of IBM
  * 5725N95, 5725P55, 5725N96
  * (C) Copyright IBM Corp. 1999, 2014.
  * US Government Users Restricted Rights- Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

 /* $Id: rlotreenav.js,v 1.1.2.2 2015/11/17 12:38:39 srmithra Exp $ */
 
TreeController = 
{
	showRoot : false,
	showIcons : false,
	tree : null,
	current : null,
	autoCollapse : true,
	init : function()
	{
		var vc = parent.ViewerController;
		vc.events.navigate.subscribe(this.handleNavigation,this,true);
		vc.events.load.subscribe(this.updateEnabled,this,true);
		vc.events.score.subscribe(this.updateEnabled,this,true);
		
		var root = vc.root;
		var t = this.tree = new YAHOO.widget.TreeView("navarea");
		
		var leaf = vc.isLeaf(root);
		if (this.showRoot || leaf)
		{
			this.addTreeNode(root,t.getRoot(),!leaf);
		}
		else
		{
			this.addTreeNodeChildren(root,t.getRoot(),true);
		}

		t.subscribe("clickEvent",TreeController.nodeClicked);
		t.subscribe("expandComplete",TreeController.nodeExpanded);
		t.render();
		
		if (vc.current != null)
		{
			this.handleNavigation("navigation",[vc.current]);
		}
	},
	addTreeNode : function(obj, parentNode, addChildren)
	{
		if (obj.type != 1)
		{
			var html = [];
			html.push("<table class=\"treetable\" border=\"0\"><tr>");
			if (this.showIcons)
			{
				html.push("<td><a href=\"#\" onclick=\"return false;\"><img class=\"treeicon\" src=\""+this.iconMap[obj.type]+"\" border=\"0\"/></a></td>");
			}
			html.push("<td><a id=\"n"+obj.uniqueId+"\" class=\"tl tloff\" href=\"#\" onclick=\"return false;\">"+obj.label+"</a></td>");
			html.push("</tr></table>");

			var n = new YAHOO.widget.HTMLNode({ html:html.join(""), obj: obj, expanded:false, hasIcon:true }, parentNode);
			
			if (addChildren)
			{
				this.addTreeNodeChildren(obj,n,true);
			}
		}
	},
	handleNavigation : function(type, args)
	{
		var obj = args[0];

		this.current = obj;
		
		var node = this.tree.getNodeByProperty("obj",obj);
		if (node != null)
		{
			if (this.autoCollapse) this.tree.collapseAll();
		
			var yd = YAHOO.util.Dom;
			
			var p = node;
			while ((p = p.parent) != null)
			{
				p.expand();
			}
			
			var yd = YAHOO.util.Dom;
			var elm = node.getEl();
			
			// auto scroll the topic into view
			if (yd.getRegion(elm).top < yd.getDocumentScrollTop())
			{
				// if the top of the element is above the visible area
				while (yd.getRegion(elm).top < yd.getDocumentScrollTop())
				{
					window.scrollTo(0,yd.getDocumentScrollTop()-1);
				}
			}
			else if (yd.getRegion(elm).bottom > (yd.getViewportHeight()+yd.getDocumentScrollTop()))
			{
				// if the bottom of the element is below the visible area
				while (yd.getRegion(elm).bottom > (yd.getViewportHeight()+yd.getDocumentScrollTop()))
				{
					window.scrollTo(0,yd.getDocumentScrollTop()+1);
				}
			}
		}
		else
		{
			this.tree.collapseAll();
		}
		
		this.updateNodeUI(this.tree.getRoot());
	},
	updateEnabled : function()
	{
		this.updateNodeUI(this.tree.getRoot());
	},
	updateNodeUI : function(node)
	{
		var yd = YAHOO.util.Dom;
		
		if (node.data && node.data.obj)
		{
			var elm = yd.get("n"+node.data.obj.uniqueId);
			if (elm != null)
			{
				elm.className = "tl";
				
				var vc = parent.ViewerController;
				
				if (this.current == node.data.obj)
				{
					yd.addClass(elm,"tlon");
					if (vc.isIdentified(node.data.obj))
					{
						yd.addClass(elm,"tlsat");
					}
				}
				else
				{
					if (!vc.isEnabled(node.data.obj))
					{
						yd.addClass(elm,"tldis");
					}
					else if (vc.isIdentified(node.data.obj))
					{
						yd.addClass(elm,"tlsat");
					}
					else
					{
						yd.addClass(elm,"tloff");
					}
				}
			}
		}

		for (var i=0; i<node.children.length; i++)
		{
			this.updateNodeUI(node.children[i]);
		}
	},
	addTreeNodeChildren : function(obj, parentNode, addChildren)
	{
		if (obj.children)
		{
			var c;
			for (var i=0; i<obj.children.length; i++)
			{
				c = obj.children[i];
				if (!parent.ViewerController.isRemoved(c))
				{
					this.addTreeNode(obj.children[i], parentNode, true);
				}
			}
		}
	},
	nodeClicked : function(e)
	{
		parent.ViewerController.navigateTo(e.node.data.obj);
		return false;
	},
	nodeExpanded : function(node)
	{
		TreeController.updateNodeUI(node);
	}
}